package com.cecf.observe;

import org.apache.flink.api.common.functions.MapFunction;
import org.apache.flink.types.Row;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

public class MapRow2QueryLog implements MapFunction<Row, QueryLogRow> {
    @Override
    public QueryLogRow map(Row row) throws Exception {
        QueryLogRow l = new QueryLogRow();
        l.hostname = (String) row.getField("hostname");
        l.queryType = (String) row.getField("type");
        l.eventDate = (LocalDate) row.getField("event_date");
        l.eventTime = (LocalDateTime) row.getField("event_time");
        l.queryStartTime = (LocalDateTime) row.getField("query_start_time");
        l.queryDurationMs = (BigDecimal) row.getField("query_duration_ms");
        l.readRows = (BigDecimal) row.getField("read_rows");
        l.readBytes = (BigDecimal) row.getField("read_bytes");
        l.writtenRows = (BigDecimal) row.getField("written_rows");
        l.writtenBytes = (BigDecimal) row.getField("written_bytes");
        l.resultRows = (BigDecimal) row.getField("result_rows");
        l.resultBytes = (BigDecimal) row.getField("result_bytes");
        l.memoryUsage = (BigDecimal) row.getField("memory_usage");
        l.currentDatabase = (String) row.getField("current_database");
        l.query = (String) row.getField("query");
        l.formattedQuery = (String) row.getField("formatted_query");
        l.normalizedQueryHash = (BigDecimal) row.getField("normalized_query_hash");
        l.queryKind = (String) row.getField("query_kind");
        Object databasesObject = row.getField("databases");
        if (databasesObject instanceof ArrayList<?>) {
            List<?> databases = (ArrayList<?>) databasesObject;
            for (Object database : databases) {
                if (database instanceof String) {
                    l.databases.add((String) database);
                }
            }
        }
        Object tableObjects = row.getField("tables");
        if (tableObjects instanceof ArrayList<?>) {
            List<?> tables = (ArrayList<?>) tableObjects;
            for (Object table : tables) {
                if (table instanceof String) {
                    l.tables.add((String) table);
                }
            }
        }
        Object colObjects = row.getField("columns");
        if (colObjects instanceof ArrayList<?>) {
            List<?> cols = (ArrayList<?>) colObjects;
            for (Object col : cols) {
                if (col instanceof String) {
                    l.columns.add((String) col);
                }
            }
        }
        Object partObjects = row.getField("partitions");
        if (partObjects instanceof ArrayList<?>) {
            List<?> parts = (ArrayList<?>) partObjects;
            for (Object part : parts) {
                if (part instanceof String) {
                    l.partitions.add((String) part);
                }
            }
        }
        l.exceptionCode = (Integer) row.getField("exception_code");
        l.exception = (String) row.getField("exception");
        l.stackTrace = (String) row.getField("stack_trace");
        l.isInitialQuery = (Short) row.getField("is_initial_query");
        l.user = (String) row.getField("user");
        l.query_id = (String) row.getField("query_id");
        l.port = (Integer) row.getField("port");
        l.clientName = (String) row.getField("client_name");
        l.httpUserAgent = (String) row.getField("http_user_agent");
        return l;
    }
}
